//
//  UsingContextsUIView.swift
//  CoreGraphicsDemo
//
//  Created by Sarah Abraham on 11/1/16.
//  Copyright © 2016 Sarah Abraham. All rights reserved.
//

import UIKit

class UsingContextsUIView: UIView {

    override func draw(_ rect: CGRect) {
        //Extract current graphics context
        let context = UIGraphicsGetCurrentContext()
        
        //Set up information for creating a gradient
        let colors = [UIColor.purple.cgColor, UIColor.blue.cgColor]
        
        let colorSpace = CGColorSpaceCreateDeviceRGB()
        let colorLocations:[CGFloat] = [0.0, 1.0]
        
        let gradient = CGGradient(colorsSpace: colorSpace, colors: colors as CFArray, locations: colorLocations)
        
        let startPoint = CGPoint.zero
        let endPoint = CGPoint(x:0, y:self.bounds.height)
        
        //Draw the gradient
        context?.drawLinearGradient(gradient!, start: startPoint, end: endPoint, options: [.drawsBeforeStartLocation, .drawsAfterEndLocation])
        
        
        //Save out context state before applying transformations
        context?.saveGState()
        
        //Create shape to be transformed about its origin
        let rectOrigin = CGPoint(x:-bounds.width/4, y:-bounds.height/4)
        let rectSize = CGSize(width: bounds.width/2, height: bounds.height/2)
        let rectangle = UIBezierPath(rect: CGRect(origin: rectOrigin, size: rectSize))
        
        UIColor.white.setFill()
        rectangle.fill()

        context?.translateBy(x: bounds.width/2, y: bounds.height/2)
        
        UIColor.gray.setFill()
        rectangle.fill()

        //Perform affine transformations
        context?.rotate(by: -0.39)
        
        //Draw the shape in the transformed context
        UIColor.black.setFill()
        rectangle.fill()
        
        //Restore context to initial state
        context?.restoreGState()
        
    }

}
